# -*- coding: utf-8 -*- #
# Copyright 2024 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""The command group for Cloud Quotas AdjusterSettings."""

from googlecloudsdk.calliope import base


@base.ReleaseTracks(base.ReleaseTrack.BETA)
@base.UniverseCompatible
class QuotaAdjusterSettingsBeta(base.Group):
  """The command group for Cloud Quotas AdjusterSettings.

  A QuotaAdjusterSettings resource represents your adjuster setting for a
  particular project. Enable this to automatically adjust quotas.
  """


@base.Hidden
@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
@base.UniverseCompatible
class QuotaAdjusterSettingsAlpha(base.Group):
  """The command group for Cloud Quotas AdjusterSettings.

  A QuotaAdjusterSettings resource represents your adjuster setting for a
  particular project. Enable this to automatically adjust quotas.
  """
